<?php

/**
 * @file
 * Contains the class to extend views display plugins with
 * Filter by Current Language checkbox.
 */

/**
 * The plugin to filter view's results by current site language.
 *
 * @ingroup views_display_plugins
 */
class i18n_views_fbcl_plugin_display_extender extends views_plugin_display_extender {
  /**
   * Provide a form to edit options for this plugin.
   */
  function option_definition(&$options) {
    $options['i18n_views_fbcl'] = array('default' => '');
  }

  /**
   * Provide the form to set the Filter by Current Language checkbox.
   */
  function options_form(&$form, &$form_state) {
    switch ($form_state['section']) {
      case 'i18n_views_fbcl':
        $form['#title'] .= t('Filter by Site Language');

        $form['i18n_views_fbcl'] = array(
          '#type' => 'checkbox',
          '#title' => t('Filter results by current site language'),
          '#description' => t('This will make the view display only content with the same language as current site language. If not checked, view will display all languages content.'),
          '#default_value' => $this->display->get_option('i18n_views_fbcl'),
        );
        break;
    }
  }

  /**
   * Summarize the field.
   *
   * List the field as either 'Yes' if is checked or 'None' otherwise and
   * categorizes the fields under the 'Other' category.
   */
  function options_summary(&$categories, &$options) {
    $options['i18n_views_fbcl'] = array(
      'category' => 'other',
      'title' => t('Filter by Site Language'),
      'value' => ($this->display->get_option('i18n_views_fbcl')) ? t('Yes') : t('None'),
      'desc' => t('Filter results by current site language for this display.'),
    );
  }

  /**
   * Inject language condition into the query that the display_extender
   * handler needs.
   */
  function query() {
    global $language;

    $this->table_alias = $this->display->view->query->ensure_table('node');
    if (empty($this->table_alias)) {
      return;
    }

    if ($this->display->get_option('i18n_views_fbcl')) {
      $this->display->view->query->add_where(0, "$this->table_alias.language", $language->language, "=");
    }
  }
}
